#
# spec file for package libsigc++3
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name libsigc++
Name:           libsigc++3
Version:        2.99.10
Release:        lp150.2.1
Summary:        Typesafe Signal Framework for C++
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://libsigc.sourceforge.net/
Source:         http://download.gnome.org/sources/libsigc++/2.99/%{_name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
This library implements a full callback system for use in widget
libraries, abstract interfaces, and general programming. It is the most
complete library of its kind with the ability to connect an abstract
callback to a class method, function, or function object. It contains
adaptor classes for connection of dissimilar callbacks and has an ease
of use unmatched by other C++ callback libraries.

%package -n libsigc-3_0-0
Summary:        Typesafe Signal Framework for C++
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libsigc-3_0-0
This library implements a full callback system for use in widget
libraries, abstract interfaces, and general programming. It is the most
complete library of its kind with the ability to connect an abstract
callback to a class method, function, or function object. It contains
adaptor classes for connection of dissimilar callbacks and has an ease
of use unmatched by other C++ callback libraries.

%package devel
Summary:        Typesafe Signal Framework for C++
Group:          Development/Libraries/C and C++
Requires:       libsigc-3_0-0 = %{version}
Requires:       libstdc++-devel

%description devel
This library implements a full callback system for use in widget
libraries, abstract interfaces, and general programming. It is the most
complete library of its kind with the ability to connect an abstract
callback to a class method, function, or function object. It contains
adaptor classes for connection of dissimilar callbacks and has an ease
of use unmatched by other C++ callback libraries.

%prep
%setup -q -n %{_name}-%{version}

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
export MALLOC_CHECK_=2 MALLOC_PERTURB_=$((${RANDOM:-256} % 256))
make %{?_smp_mflags} check
unset MALLOC_CHECK_ MALLOC_PERTURB_

%post -n libsigc-3_0-0 -p /sbin/ldconfig
%postun -n libsigc-3_0-0 -p /sbin/ldconfig

%files -n libsigc-3_0-0
%license COPYING
%doc NEWS README
%{_libdir}/libsigc-3.0.so.*

%files devel
%doc AUTHORS ChangeLog
%doc %{_datadir}/doc/%{_name}-3.0
%{_libdir}/libsigc-3.0.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/sigc++-3.0
%{_includedir}/sigc++-3.0/
%{_datadir}/devhelp/books/%{_name}-3.0
# Avoid BuildRequires on devhelp
%dir %{_datadir}/devhelp
%dir %{_datadir}/devhelp/books

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Jan 11 2018 luc14n0@linuxmail.org
- Update to version 2.99.10:
  + slot_base::set_parent(): Create a dummy slot_rep if necessary
    (bgo#167714).
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 2.99.9:
  + signal_impl::clear(): Don't clear the slot list during signal
    emission, to prevent a segfault. And add a test for this
    (bgo#784550).
  + Remove signal_base::erase() and signal_impl::erase()
    (bgo#784550).
  + Various minor code cleanups.
  + Windows: Update the MS Visual Studio build.
- Move AUTHORS, ChangeLog, NEWS, README to devel package, mainly
  developers would care for those files, silence a rpmlint warning.
* Tue Feb 14 2017 zaitor@opensuse.org
- Update to version 2.99.8:
  + signal_impl:
  - Use std::weak_ptr<signal_impl> in connected slots, to avoid a
    memory leak (bgo#775871).
  - clear(): Really avoid erasing the slots prematurely.
  + slot_rep: Make destructor, destroy, and clone() virtual,
    instead of using function pointers that do the same thing
    (bgo#777618).
  + Build:
  - Visual Studio builds: Require Visual Studio 2017.
  - Add tests/memleakcheck.sh, to run the tests under valgrind
    (bgo#775871).
  + Make --disable-benchmark work (bgo#774732).
  + Make silent builds really silent (bgo#768797).
* Mon Dec  5 2016 jengelh@inai.de
- RPM group reassignment
* Mon Jun 27 2016 zaitor@opensuse.org
- Update to version 2.99.7:
  + connection, slot_base: Use an internal::weak_raw_ptr<> to
    simplify the code.
  + signal_base: Do not derive from trackable.
  + slot_rep: Pass a slot_rep*, not notifiable*, to destroy().
  + signal_impl: Do not derive from notifiable.
* Thu May  5 2016 jengelh@inai.de
- Remove pointless --with-pic because shared libs are always
  built with it anyway
* Sat Apr 30 2016 zaitor@opensuse.org
- Update to version 2.99.6:
  + signal:
  - Remove slots() and the container that it returns, and the
    iterator for that container.
  - connect(): Return a connection, instead of an iterator that
    can be implicitly converted to a connection.
  + Use std::shared_ptr<> for signal_impl reference-counting.
    Instead of manual reference-counting (bgo#764935).
  + slot: Use unique_ptr<> to avoid direct call of destructor
    (bgo#764935).
  + Add optional benchmark code, using boost::timer.
  + Make some single-item constructors explicit.
  + Make some member variables and methods private.
  + Remove _ and __ prefixes on variables and parameters.
  + Header guards: Remove leading underscores (and trailing
    underscores).
  + limit_derived_target<T_Target>: Rename to
    limit_trackable_target<> and visit_each_type<T_Type>() to
    visit_each_trackable() to make their purpose more obvious.
* Thu Apr 14 2016 zaitor@opensuse.org
- Update to version 2.99.5:
  + Functors (mem_functor, ptr_functor) no longer need to derive
    from a common functor_base base class, and functors no longer
    need to have a result_type typedef or alias.
  + Emitters and accumulators no longer need to have a result_type
    typedef or alias.
  + Remove now-unnecessary adaptor_type type aliases.
  + Remove some more unused and unnecessary public type aliases.
* Fri Apr  8 2016 dimstar@opensuse.org
- Update to version 2.99.4:
  + Minor documentation improvements.
  + Make some constructors explicit.
  + Some more minor uses of C++11 syntax.
  + Remove unused SIGC_FUNCTORS_DEDUCE_RESULT_TYPE_WITH_DECLTYPE.
  + Reformat code with clang-format.
* Fri Mar 18 2016 dimstar@opensuse.org
- Update to version 2.99.3:
  + bgo#763616: Correct the license of some header files from GPL
    to LGPL.
- Change License to LGPL-3.0+ following upstreams changes.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 2.99.2:
  + slots and signal: These should now be declared with the
    sigc::slot<R(Args...)> and sigc::signal<R(Args...)>
    syntax, like std::function<>. Version 2.9/2.10 of libsigc++-2.0
    supports both the old and new syntax.
  + sigc::men_fun(): Take the instance by reference only.
* Wed Mar  9 2016 zaitor@opensuse.org
- Initial packaging of libsigc++3 based on libsigc++2.
